@@ -13,15 +13,22 @@ use warnings;
 # restriction could be listed.
 use 5.010; 
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Carp;
 
 use Tangence::Constants;
 
+use Tangence::Class;
+use Tangence::Meta::Method;
+use Tangence::Meta::Event;
+use Tangence::Meta::Property;
+use Tangence::Meta::Argument;
 use Tangence::Meta::Type;
 use Tangence::Struct;
 
+use Tangence::Object;
+
 use Encode qw( encode_utf8 decode_utf8 );
 use Scalar::Util qw( weaken );
 
